@@ -209,7 +209,7 @@ get_path (MuMsg *self)
 
 	/* shouldn't happen */
 	if (!val)
-		g_warning ("%s: cannot find path", __FUNCTION__);
+		g_warning ("%s: cannot find path", __func__);
 
 	return free_later_str (self, val);
 }
@@ -376,8 +376,20 @@ mu_msg_get_msgid  (MuMsg *self)
 const char*
 mu_msg_get_mailing_list (MuMsg *self)
 {
+	const char	*ml;
+	char		*decml;
+
 	g_return_val_if_fail (self, NULL);
-	return get_str_field (self, MU_MSG_FIELD_ID_MAILING_LIST);
+
+	ml = get_str_field (self, MU_MSG_FIELD_ID_MAILING_LIST);
+	if (!ml)
+		return NULL;
+
+	decml = g_mime_utils_header_decode_text (ml);
+	if (!decml)
+		return NULL;
+
+	return free_later_str (self, decml);
 }
 
 
@@ -465,21 +477,20 @@ accumulate_body (MuMsg *msg, MuMsgPart *mpart, BodyData *bdata)
 	char *txt;
 	gboolean err;
 
-	/* if it looks like an attachment, skip it */
-	if (mpart->part_type & MU_MSG_PART_TYPE_ATTACHMENT)
-		return;
-
 	if (!GMIME_IS_PART(mpart->data))
 		return;
 
 	txt = NULL;
 	err = TRUE;
 
+	/* text-like attachments are included when in text-mode */
+
 	if (!bdata->want_html &&
 	    (mpart->part_type & MU_MSG_PART_TYPE_TEXT_PLAIN))
 		txt = mu_msg_mime_part_to_string (
 			(GMimePart*)mpart->data, &err);
-	else if (bdata->want_html &&
+	else if (!(mpart->part_type & MU_MSG_PART_TYPE_ATTACHMENT) &&
+		 bdata->want_html &&
 		 (mpart->part_type & MU_MSG_PART_TYPE_TEXT_HTML))
 		txt = mu_msg_mime_part_to_string (
 			(GMimePart*)mpart->data, &err);
