@@ -1,6 +1,6 @@
 /* -*-mode: c; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-*/
 /*
-** Copyright (C) 2010-2013 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
+** Copyright (C) 2010-2016 Dirk-Jan C. Binnema <djcb@djcbsoftware.nl>
 **
 ** This program is free software; you can redistribute it and/or modify it
 ** under the terms of the GNU General Public License as published by the
@@ -80,10 +80,14 @@ each_part (MuMsg *msg, MuMsgPart *part, gchar **attach)
 static gchar *
 get_attach_str (MuMsg *msg, MuConfig *opts)
 {
-	gchar *attach;
+	gchar		*attach;
+	MuMsgOptions	 msgopts;
+
+	msgopts = mu_config_get_msg_options(opts) |
+		MU_MSG_OPTION_CONSOLE_PASSWORD;
 
 	attach = NULL;
-	mu_msg_part_foreach (msg, mu_config_get_msg_options(opts),
+	mu_msg_part_foreach (msg, msgopts,
 			     (MuMsgPartForeachFunc)each_part, &attach);
 	return attach;
 }
@@ -436,38 +440,40 @@ each_sig (MuMsg *msg, MuMsgPart *part, VData *vdata)
 
 
 static void
-print_verdict (VData *vdata, gboolean color)
+print_verdict (VData *vdata, gboolean color, gboolean verbose)
 {
  	g_print ("verdict: ");
 
 	switch (vdata->combined_status) {
 	case MU_MSG_PART_SIG_STATUS_UNSIGNED:
-		g_print ("%s", "no signature found");
+		g_print ("no signature found");
 		break;
 	case MU_MSG_PART_SIG_STATUS_GOOD:
 		color_maybe (MU_COLOR_GREEN);
-		g_print ("%s", "signature(s) verified");
+		g_print ("signature(s) verified");
 		break;
 	case MU_MSG_PART_SIG_STATUS_BAD:
 		color_maybe (MU_COLOR_RED);
-		g_print ("%s", "bad signature");
+		g_print ("bad signature");
 		break;
 	case MU_MSG_PART_SIG_STATUS_ERROR:
 		color_maybe (MU_COLOR_RED);
-		g_print ("%s", "verification failed");
+		g_print ("verification failed");
 		break;
 	case MU_MSG_PART_SIG_STATUS_FAIL:
 		color_maybe(MU_COLOR_RED);
-		g_print ("%s", "error in verification process");
+		g_print ("error in verification process");
 		break;
 	default: g_return_if_reached ();
 	}
 
 	color_maybe (MU_COLOR_DEFAULT);
-	if (vdata->report)
+	if (vdata->report && verbose)
 		g_print ("%s%s\n",
 			 (vdata->oneline) ? ";" : "\n",
 			 vdata->report);
+	else
+		g_print ("\n");
 }
 
 
@@ -492,7 +498,9 @@ mu_cmd_verify (MuConfig *opts, GError **err)
 	if (!msg)
 		return MU_ERROR;
 
-	msgopts = mu_config_get_msg_options (opts) | MU_MSG_OPTION_VERIFY;
+	msgopts = mu_config_get_msg_options (opts)
+		| MU_MSG_OPTION_VERIFY
+		| MU_MSG_OPTION_CONSOLE_PASSWORD;
 
 	vdata.report  = NULL;
 	vdata.combined_status = MU_MSG_PART_SIG_STATUS_UNSIGNED;
@@ -502,7 +510,7 @@ mu_cmd_verify (MuConfig *opts, GError **err)
 			     (MuMsgPartForeachFunc)each_sig, &vdata);
 
 	if (!opts->quiet)
-		print_verdict (&vdata, !opts->nocolor);
+		print_verdict (&vdata, !opts->nocolor, opts->verbose);
 
 	mu_msg_unref (msg);
 	g_free (vdata.report);
