@@ -115,7 +115,6 @@ for querying the message information."
   :type '(choice (const :tag "move message to mu4e-sent-folder" sent)
 	   (const :tag "move message to mu4e-trash-folder" trash)
 	   (const :tag "delete message" delete))
-  :safe 'symbolp
   :group 'mu4e-compose)
 
 
@@ -135,10 +134,10 @@ contexts match, we have the following choices:
 
 Also see `mu4e-context-policy'."
   :type '(choice
-	   (const :tag "Always ask what context to use" 'always-ask)
-	   (const :tag "Ask if none of the contexts match" 'ask)
-	   (const :tag "Ask when there's no context yet" 'ask-if-none)
-	   (const :tag "Pick the first context if none match" 'pick-first)
+	   (const :tag "Always ask what context to use" always-ask)
+	   (const :tag "Ask if none of the contexts match" ask)
+	   (const :tag "Ask when there's no context yet" ask-if-none)
+	   (const :tag "Pick the first context if none match" pick-first)
 	   (const :tag "Don't change the context when none match" nil)
 	   :safe 'symbolp
 	   :group 'mu4e-compose))
@@ -153,9 +152,9 @@ We have the following choices:
 - `encrypt': encrypt the reply, but don't sign it.
 -  anything else: do nothing."
   :type '(choice
-	   (const :tag "Sign the reply" 'sign)
-	   (const :tag "Sign and encrypt the reply" 'sign-and-encrypt)
-	   (const :tag "Encrypt the reply" 'encrypt)
+	   (const :tag "Sign the reply" sign)
+	   (const :tag "Sign and encrypt the reply" sign-and-encrypt)
+	   (const :tag "Encrypt the reply" encrypt)
 	   (const :tag "Don't do anything" nil)
 	   :safe 'symbolp
 	   :group 'mu4e-compose))
@@ -763,7 +762,10 @@ draft message."
 
   ;; add any other headers specified
   (when other-headers
-    (message-add-header other-headers))
+    (dolist (h other-headers other-headers)
+      (if (symbolp (car h)) (setcar h (symbol-name (car h))))
+      (message-add-header (concat (capitalize (car h)) ": " (cdr h) "\n"  ))
+      ))
 
   ;; yank message
   (if (bufferp yank-action)
